/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Preparation of data on children (00-2_children.do), 
* executed by data preparation master 00_preparation.do
*
* In SHARE, most information about families is provided by the so-called family respondent. 
* The family respondent reports basic information on all own and/or partner's children. 
* From all reported children, up to four children are selected to collect more detailed information. 
* This includes, for example, educational level or occupation of the child, but also information on children of the child, 
* which is vital for our analysis of grandparenting. 
* 
* For each wave
* 1) prepare data for all children (sex, year of birth, geographical distance) + generate a wave-specific child number
* 2) prepare detailed data for up to 4 selected children 
*   (SHARE offers detailed data on up to 4 reported children, including the birth year of youngest child of the child)
* 3) merge (2) to (1): all children in long format, for selected ones, additional detailed information
* 4) generate child-level variables (e.g., age of child at time of interview, age of youngest child of child)
* 5) generate variables aggregated over children (e.g., age of youngest child/grandchild)
*
* Note: Information on children has been provided by the family respondent only. 
* 
* Produced data output in temporary folder: 
* - Wave 1: 00-2_children_wave1.dta
* - Wave 2: 00-2_children_wave2.dta
* 
* Both output files have a two-level structure (long format) with children on the first level nested in 
* respondents/couples on the second level.
* 
**********************************************************************/

* loop over wave-specific data files
foreach wave of numlist 1/2 {

quiet log on dataselection
di as txt "**********************************************"
di as txt "Preparing children_wave`wave'"
di as txt "**********************************************"
quiet log off dataselection

* for some variables there is a suffix in wave 2
if `wave'==2 local suffix "_w2" 

tempfile childlong childdetail 

********************************************
* 1.) prepare data for all children 
*     (number of child, sex, year of birth, where does live)
*    --> tempfile "childlong"
********************************************
use "${wave`wave'}/sharew`wave'_${rel}_ch",  clear

* merge dummy for family respondent
merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_cv_r", assert(match using) keep(match) keepusing(dumfamr cvidp) nogen
* sort correctly
sort hhid`wave' cvid
* check: only values for family respondents
assert  ch001_==. & ch002_==. & ch005_1==. if dumfamr==0
* only keep rows from family respondents
keep if dumfamr==1
* recode missing values
sharetom _all, replace
* keep relevant variables
keep mergeid hhid`wave' cvid cvidp ch001_ ch002_ ch005* ch006* ch007* ch021_ ch022_

* drop cases that do not provide child information or that do not have children
quiet log on dataselection
drop if mi(ch001_) | ch001_==0
quiet log off dataselection

* reshape data file to long format
reshape long ch005_ ch006_ ch007_ , i(mergeid) j(child)
* remove empty rows
drop if ch005_==. & ch006_==. & ch007_==.
* there is one respondent having a reported number of children (ch001_=17) that does not equal the 
* actual collected number of children (16 rows)
* ==> correct this by recoding ch001 to the number of child rows!
by mergeid, sort: gen N = _N
li hhid`wave' child N ch001_ if N!=ch001_, noobs
replace ch001_ = N if N!=ch001_ 
drop N
* labeling
lab var child "child: number"
lab var ch005_ "child: sex"
lab var ch006_ "child: year of birth"
lab var ch007_ "child: where living"
count 

* generate a family respondent ID
clonevar famresid = mergeid
lab var famresid "Family respondent merge-id"
order famresid mergeid hhid`wave' cvid cvidp child, first

* check
isid famresid child 
* save children data in long format (all children)
save `childlong'

log on dataselection
********************************************
* 2.) prepare detailed data for up to 4 children
*     --> tempfile "childdetail"
********************************************
log off dataselection
use "${wave`wave'}/sharew`wave'_${rel}_ch",  clear
* merge generated variables for ISCED of children (up to 4)
merge 1:1 mergeid using "${wave`wave'}/sharew`wave'_${rel}_gv_isced", assert(match) keepusing(isced_c1 isced_c2 isced_c3 isced_c4) nogen
* add dummy for family respondent by merge (keep only matched obs)
merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_cv_r", assert(match using) keep(match) keepusing(dumfamr cvidp) nogen
* sort correctly
sort hhid cvid
* check: only values for family respondents
assert  ch001_==. & ch002_==. & ch005_1==. if dumfamr==0
* keep family respondents
keep if dumfamr==1
* recode missing values
sharetom _all, replace
* remove cases without child information
drop if mi(ch001_) | ch001_==0
* keep relevant variables
keep mergeid  hhid`wave' cvid  ch001_ ch010_? ch011_? ch012_? ch013_? ch014_? ch015_? ch016_? ch019_? ch020_? isced_c? chselch?
* reshape data file to long format
reshape long ch010_ ch011_ ch012_ ch013_ ch014_ ch015_ ch016_ ch019_ ch020_ isced_c chselch, i(mergeid) j(n)

* remove empty rows (children not selected for detailed questions)
drop if chselch==0  
* Handle data problems
* 1) data problem: drop superfluous selected child lines
* (i.e. there are values in chselch[1-4] that refer to a non-existent child)
* example: bro if hhid == "DE-188870-A" & cvid==1
drop if n > ch001_ 
* 2) data problem: chselch[1-4] do not contain unique child numbers 
* e.g. 
duplicates report hhid`wave' cvid chselch
duplicates list hhid`wave' cvid chselch
* Solution: drop duplicates with higher indices
isid hhid`wave' cvid chselch n
sort hhid`wave' cvid chselch n
duplicates drop hhid`wave' cvid chselch, force 
* unique: hhid cvid chselch?
isid hhid`wave' cvid chselch

* gen child identificator for merging
rename chselch child
* labeling
lab var ch010_ "child: step adoptive or foster (selected) child"
lab var ch011_ "child: own (selected) child"
lab var ch012_ "child: marital status of (selected) child"
lab var ch013_ "child: does (selected) child have partner"
lab var ch014_ "child: contact with (selected) child"
lab var ch015_ "child: year (selected) child moved from household"
lab var ch019_ "child: number of children of (selected) child" 
lab var ch020_ "child: year of birth youngest child of (selected) child"
lab var isced_c "child: ISCED-97 coding of education (selected) child"
lab var ch016_ "child: selected child occupation"
lab var n "child: selected child index chselch[?]"

* generate an ID for family respondent
clonevar famresid = mergeid
lab var famresid "Family respondent merge-id"

* drop mergeid
drop mergeid ch001_

* Check
isid famresid child

* save detail data
save  `childdetail'

****************************************
* 3.) Merge data with details up to 4 children 
*     to all children
****************************************

* merge details to long file
use `childlong', clear
if `wave' == 1 {
	merge 1:1 famresid child using `childdetail', assert(match master) 
}
if `wave' == 2 {
	* 4 surplus cases in childdetail (why?) resulting in a _merge==2 for wave 2
	merge 1:1 famresid child using `childdetail'
	drop if _merge == 2
}
gen childdetail = _merge==3
lab var childdetail "Details on child available"
drop _merge


****************************************
* 4) Generate additional 
*    child level variables
*	 - age of child at interview
*	 - age of youngest child of child (=grandchild) at date of interview
*	 - geographical distance to child
*	 - family respondent's and spouse's/partner's biological relation to child
****************************************
* get interview date
merge n:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_cv_r", assert(match using) keep(match) nogen keepusing(int_* )
isid hhid`wave' cvid child
sort hhid`wave' cvid child

* cage: age of child at date of interview
gen cage = floor((ym(int_year`suffix', int_month`suffix') - ym(ch006_, 7))/12)
replace cage = 0 if cage < 0
lab var cage "child: age"
* Remind: check for inplausible values later!

* cycage: age of youngest child of child at date of interview
gen cycage = floor((ym(int_year`suffix', int_month`suffix') - ym(ch020_, 7))/12)
replace cycage = 0 if cycage < 0
lab var cycage "child: age of youngest child of child"
* Remind: check for inplausible values later!

* cdist: distance to child (collapsed version)
recode ch007_ (1 2 = 1 "same house or hh") ///
			  (3 4 = 2 "0km - 5km") ///
			  (5 = 3   "5km - 25km") ///
			  (6 = 4   "25km - 100km") ///
			  (7 8 9 = 5 "> 100km") ///
			  (.a = .a "don't know") ///
			  (.b = .b "refusal"), gen(cdist)
lab var cdist "distance to child"

* cstat: biological relation of child to parent
gen cstat = .
* ch002_: "Is this child a natural child/Are all these children natural children of your own [and your current spouse or partner]?"
* 1 = yes, 5 = no
replace cstat = 1 if ch002_==1 & !mi(cvidp) 
replace cstat = 2 if ch002_==1 & mi(cvidp) 
replace cstat = 1 if ch011_==1 & ch002_==5
replace cstat = 2 if ch011_==2 & ch002_==5
replace cstat = 2 if ch010_==1 & ch002_==5
replace cstat = 3 if ch011_==3 & ch002_==5	
replace cstat = 4 if inlist(ch011_, 4,5,6) & ch002_==5 // with partner: adopted, foster, other
replace cstat = 4 if inlist(ch010_, 2,3,4) & ch002_==5 // single: step, foster, adopted
replace cstat = .a if cstat==. 
lab def cstat 1 "child of both" ///
			  2 "child of fam. respond." ///
			  3 "child of partner" ///
			  4 "other child" ///
			  .a "not determinable"
lab val cstat cstat
lab var cstat "child: status of parent"
* check: 
assert cstat != 1 if cvidp == .

****************************************
* 5) Generate additional 
*    variables aggregated over children (age of youngest child/grandchild)
*	- age of youngest child
*	- age of youngest grandchild
****************************************

* rageyc: age of youngest child of respondent/couple 
by mergeid, sort: egen rageyc = min(cage)
lab var rageyc "couple/resp.: age of youngest child" 
* rageyc: age of youngest grandchild of respondent/couple 
by mergeid, sort: egen rageygc = min(cycage)
lab var rageygc "couple/resp.: age of youngest grandchild" 

drop int_* 
* generate a simple wave indicator
gen wave = `wave'
order wave, after(hhid`wave')
order childdetail, before(n)

lab data "Prepared children data with details to up to 4 children in long format."
note: "One row per child; merge via famresid, mergeid, or hhid`wave' cvid" 


* correct one case manually
if `wave' == 1 {
	replace ch011_ = 3 if mergeid=="DE-844061-01" & wave == 1 // & mergeid2=="DE-844061-02" & wave==1 
	replace cstat = 3 if mergeid=="DE-844061-01" & wave == 1 // & mergeid2=="DE-844061-02" & wave==1 
}

save "${tempDir}/00-2_children_wave`wave'", replace
}
