/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Preparation of data on looking after grandchildren (00-3_grandparenting.do), 
* executed by data preparation master 00_preparation.do
*
* Note: In contrast to the children data, which is provided by the family respondent only,
*	    information on grandparenting (looking after grandchildren of child) has been 
*		provided by all respondents. This enables us to study grandparents jointly as couples.
* 
* Information on looking after grandparents is surveyed from all respondents whi have grandchildren. 
* If a respondent reported to look after grandchildren in the absence of parents, he/she
* was asked how frequent and how intense (in hours) this support was (separately for each child who had grandchildren). 
* 
* Produces data output in temporary folder: 
* - Wave 1: 00-3_grandparenting_wave1.dta
* - Wave 2: 00-3_grandparenting_wave2.dta
* 
* Both output files have a two level structure (long format) with children on the first level nested in 
* respondents on the second level.
*
**********************************************************************/

* loop over wave specific files
foreach wave of numlist 1/2 {

quiet log on dataselection
di as txt "**********************************************"
di as txt "Preparing grandparenting_wave`wave'"
di as txt "**********************************************"
quiet log off dataselection

* 1) load data from sp module, add cvid of partner, add dummy for family respondent, and keep only relevant variables 
use "${wave`wave'}/sharew`wave'_${rel}_sp", clear
* merge dummy for family respondent
merge 1:1 hhid`wave' cvid using "${wave`wave'}/sharew`wave'_${rel}_cv_r", assert(match using) keep(match) keepusing(dumfamr cvidp) nogen
order cvidp dumfamr, after(cvid)
* keep only variables in sp module that relate to grandparenting 
keep mergeid hhid`wave' cvid dumfamr cvidp sp014_ sp015* sp016_* sp017_* 
sharetom _all, replace


/* 
Note: Item formulation

IF CH021_(NUMBER OF GRANDCHILDREN) > 0
|
| SP014_ LOOK AFTER GRANDCHILDREN
| During the last twelve months, have you regularly or occasionally
| looked after [your grandchild/your grandchildren] without the
| presence of the parents?
| 1. Yes
| 5. No
|
| IF SP014_ (LOOK AFTER GRANDCHILDREN) = 1. Yes
| |
| | SP015_ PARENTS FROM GRANDCHILDREN
| | From which of your children [is/are] [the grandchild/the
| | grandchildren] you have looked after?
| | IWER: CODE ALL THAT APPLY
| | {list with children}
| |
| | LOOP cnt = 1 TO 20
| | |
| | | IF cnt IN SP015_(PARENTS FROM GRANDCHILDREN)
| | | |
| | | | SP016_ HOW OFTEN DO YOU LOOK AFTER GRANDCHILDREN
| | | | On average, how often did you look after the child(ren) of [{child
| | | | name}] in the last twelve months? Was it...
| | | | IWER: READ OUT
| | | | 1. Almost daily
| | | | 2. Almost every week
| | | | 3. Almost every month
| | | | 4. Less often
| | | |
| | | | SP017_ HOURS LOOKING AFTER GRANDCHILDREN
| | | | About how many hours did you look after the child(ren) of [{child
| | | | name}] [on a typical day/in a typical week/in a typical month/in the
| | | | last twelve months]?
| | | | IWER: ROUND UP TO FULL HOURS
| | | | ___________
| | | |
| | | ENDIF
| | |
| | ENDLOOP
| |
| ENDIF
|
ENDIF
	
*/


* 2) Transpose data set to long format
* re-arrange data set to long format (person-child rows)
reshape long sp015d sp016_ sp017_, i(mergeid) j(child)
* provide labels
lab var sp015d "grandp.-child: looked after child of child"
lab var sp016_ "grandp.-child: how often do you look after child of child"
lab var sp017_ "grandp.-child: hours looking after child of child"
lab val sp016_ often3
lab val sp017_ sp017

* correct data error: recode zero value in sp017_ to missing if sp016_ is missing (1 obs in wave 1)
replace sp017_=. if mi(sp016_) & sp017_==0

/* 
Note:
expanded data set.

Variables
	child	id of child (wave specific)
	sp014_   look after grandchildren
	sp015d 	looked after child of child "child" (1 = selected, 0 = not selected)
	sp016_   how often do you look after child of child
	sp017_   hours looking after child of child
*/

* check integrity: hours spend == . if interval == .
assert sp017_ == . if sp016_==.
* check integrity: interval == . 
assert sp016_ == . if sp015d == 0
* check integrity: sp015d & sp016 & sp017 == . if sp014_ == .
assert sp015d==. & sp016_== . & sp017_==. if sp014_==. // true if sp014 was skipped (since there are no grandchildren)
assert sp015d==. & sp016_== . & sp017_==. if sp014_>. // true also for don't knows / refusals on sp014

* 3) create empty variable "weekhours" (will be needed later)  
* create an empty weekhours variable here (for compatibility reasons) 
gen double weekhours = .

* 4) generate a simple wave indicator
gen wave = `wave'
order wave, after(hhid`wave')

* label data
lab data "Prepared grandparenting data in long format."

* save
save "${tempDir}/00-3_grandparenting_wave`wave'", replace
}
