/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Descriptive analyses (30-1_description_gendergap.do), 
* executed by analysis master 30_analysis.do
* 
* Descriptive analyses cover 
* - sample description: couples and observations
* - Table 1. Variables and Descriptive Statistics 
* - Table 2. Market Work and Grandparenting in 10 European Countries
* - Figure 1. Total Hours and Share of Grandparenting and Market Work
* 
***********************************************************************/

* load analytical data set
use "${tempDir}/20_variables_imputation.dta", clear

* drop cases with missing share of grandfather (gfshr) since there are no hours performed by the couple
drop if cplsumwkhrs_impmod3==0	// -120 observations


**
* Generate additional variables
**

* generate variables
gen gfshr = gfshr_impmod3
gen cplsumwkhrs = cplsumwkhrs_impmod3
gen gfcarehrs = gfcarehrs_impmod3
gen gmcarehrs = gmcarehrs_impmod3

* number of children to whom care is provided
* gen a variable: care to more than 1 child
capt drop caretomore
gen caretomore = caredchild > 1

* generate dummies for limitation status of couples
tab cpllimit, gen(lim_)

* generate dummy for retired/inactive couples
gen ret = (empcf == 5)

* GF's share only for working couples
* Jobhours and jobshare (only defined for ret=0, i.e. active/non-retired couples)
gen nr_cpljobhrs = cpljobhrs if ret==0
gen nr_gfjobshr = gfjobshr if ret==0
gen nr_gmjobshr = gmjobshr if ret==0
gen nr_gfjobhrs = gfjobhrs if ret==0
gen nr_gmjobhrs = gmjobhrs if ret==0

* grandmother's share
gen double gmshr = 100-gfshr
* caring and sharing for ret=0 (active/non-retired couples)
gen nr_gfshr = gfshr if ret==0
gen nr_gmshr = gmshr if ret==0
gen nr_cplsumwkhrs = cplsumwkhrs if ret==0
gen nr_gfcarehrs = gfcarehrs if ret==0
gen nr_gmcarehrs = gmcarehrs if ret==0
* caring and sharing for ret=1  (inactive/retired couples)
gen r_cplsumwkhrs = cplsumwkhrs if ret==1
gen r_gfcarehrs = gfcarehrs if ret==1
gen r_gmcarehrs = gmcarehrs if ret==1
gen r_gfshr = gfshr if ret==1
gen r_gmshr = gmshr if ret==1



****************************************************************
* Sample Description: Couples and Observations (page 8 & 9)
****************************************************************

* Section: Data and Methods - Sample (page 8)
count 	// N=5,180
assert `r(N)'==5180
* couples per wave
tab wave	
count if wave==1 // 2,840 wave 1
assert `r(N)'==2840
count if wave==2 // 2,340 wave 2
assert `r(N)'==2340 

* observations and couples over all
* 5, 180 obs, 4,093 distinct couples
distinct hhid
 
* (page 9)
* 63.98% of pooled couples retired
tab ret, miss
* in 92.76% of retired couples, the grandfather was retired 
tab gfretired if ret==1, miss
* in 63.93% or working couples the grandfather was working fulltime;
* 23.95% dual fulltime earner
tab empcf if ret==0, miss

* description of the longitudinal sub sample (couples with two observations)
preserve
	by hhid (wave), sort: gen N = _N
	keep if N==2
	keep hhid wave empcf gfshr g?ep005
	reshape wide empcf gfshr gfep005 gmep005, i(hhid) j(wave)
	* number of couples observed in both waves (page 9)
	count // 1087 couples
	assert `r(N)' == 1087
	
	* transitions in employment configurations
	tab empcf1 empcf2
	
	* number of couples who worked at Wave 1 (page 9)
	count if empcf1!= 5	// 428
	
	* Number of working couples who changed employment status in wave 2 (page 9)
	count
	local total `r(N)'
	count if empcf1!=empcf2	// n=201
	local changed `r(N)'
	di `changed'/`total'
	
	* Number of working couples who changed to retirement in wave 2 (page 9)
	count if inlist(empcf1,1,2,3,4) & empcf2==5		// 117
	local ret `r(N)'
	di `ret'/`changed'
	
restore

************************************************
* Table 1. Variables and Descriptive Statistics
************************************************
* >>>>>>>>>
tab empcf, gen(empcf_)

* stats for wave 1
tabstat cplsumwkhrs gfshr nr_cpljobhrs nr_gmjobshr ret ///
		cplage cplygfo cplygmo cplisgt3 cplcohab shortdist mincycage gfygcnotown caretomore ///
		lim_* if wave==1, stats(mean sd min max) f(%9.3g) c(s)
* stats for wave 2
tabstat cplsumwkhrs gfshr nr_cpljobhrs nr_gmjobshr ret ///
		cplage cplygfo cplygmo cplisgt3 cplcohab shortdist mincycage gfygcnotown caretomore ///
		lim_* if wave==2, stats(mean sd min max) f(%9.3g) c(s)
* <<<<<<<<<
************************************		

*******************************************************************
* Table 2. Market Work and Grandparenting in 10 European Countries
*******************************************************************
* >>>>>>>>>
gen double share_ret = ret*100

recode country (13 = 1 "Sweden") /// 
			   (18 = 2 "Denmark") ///
			   (14 = 3 "Netherlands") ///
			   (12=5 "Germany") ///
			   (11=7 "Austria") /// 
			   (17=6 "France") /// 
			   (23=4 "Belgium") /// 
			   (16=8 "Italy") /// 
			   (15=9 "Spain") /// 
			   (19=10 "Greece"), gen(c)

gen notret = ret==0
gen double share_notret = 100*notret
* table 1 (cells)
tabstat nr_gfjobhrs nr_gmjobhrs nr_gfjobshr nr_gfcarehrs nr_gmcarehrs nr_gfshr r_gfcarehrs r_gmcarehrs r_gfshr share_ret , by(c) stats(mean) format(%9.2f) varwidth(20) 
* cases per country (1st column)
tab c
* retired/inactive vs. non-retired (numbers in super column "working couples" vs. "inactive/retired couples")
tab notret, miss
* <<<<<<<<<
************************************	


********************************************************************
* Figure 1. Total Hours and Share of Grandparenting and Market Work
********************************************************************

* define a small helper program for plotting the graph
capt program drop figure1
program def figure1 
	gen nr_gmjobhrs_plot = nr_gmjobhrs+nr_gfjobhrs
	gen nr_gmcarehrs_plot = nr_gmcarehrs+nr_gfcarehrs
	gen r_gmcarehrs_plot = r_gmcarehrs+r_gfcarehrs

	keep nr_gmcarehrs_plot r_gmcarehrs_plot nr_gfcarehrs r_gfcarehrs nr_gfshr r_gfshr nr_gmshr r_gmshr nr_gfjobshr c

	* reshape to long for dividing between active and inactive couples
	* *_1 = active couples
	* *_2 = inactive/retired couples
	gen gfcarehrs_1 = nr_gfcarehrs
	gen gfcarehrs_2 = r_gfcarehrs
	gen gmcarehrs_1 = nr_gmcarehrs_plot
	gen gmcarehrs_2 = r_gmcarehrs_plot
	gen gfshr_1 = nr_gfshr
	gen gfshr_2 = r_gfshr
	gen gmshr_1 = nr_gmshr
	gen gmshr_2 = r_gmshr
	gen gfjobshr_1 = nr_gfjobshr
	gen gfjobshr_2 = .

	reshape long gfcarehrs_ gmcarehrs_ gfshr_ gmshr_  gfjobshr_, i(c) j(n)

	capt drop status
	capt lab drop status
	gen status = n==2
	lab def status 0 "Working Couples" 1 "Retired Couples"
	lab val status status
	lab var status "working state of couples"

	set scheme s2mono
	twoway (bar gmcarehrs_ c, color(white) lcolor(black) barwidth(.40) lwidth(vthin) yaxis(1)) ///
		   (bar gfcarehrs_ c, color(gs4) lcolor(black) lwidth(vthin) barwidth(.40) yaxis(1)) ///
		   (scatter gmshr_ c, yaxis(2) msym(O) msize(small) mcolor(black) connect(l) lwidth(vthin) lcolor(black) sort(c)) ///
		   (scatter gfjobshr_ c, yaxis(2) msym(T) msize(small) mcolor(black) connect(l) lwidth(vthin) lpat(shortdash) lcolor(black) sort(c)) ///
		   , legend(lab(1 "GM's average weekly hours of grandparenting") ///
					lab(2 "GF's average weekly hours of grandparenting") ///
					lab(3 "GM's share of grandparenting") ///
			lab(4 "GF's share of market work") size(vsmall) symxsize(*.3) ///
			order(1 3 2 4) cols(2) region(lwidth(vthin) lcolor(white))) ///
		   xtitle("") /// 
		   by(status, l1title("") iytitle  note("") imargin(small)  ///
				plotregion(color(white) ) graphregion(color(white))) ///
		   ytitle("Average hours per week", axis(1) margin(medium) size(small)) /// 
		   ytitle("Share of market work / grandparenting (%)", axis(2) margin(medium) size(small)) ///
		   ylabel(0 (5) 40, axis(1) nogrid  labsize(small)) ymtick(0 (2.5) 40, axis(1) labsize(vsmall) )  /// 
		   xlabel(1(1)10 , valuelabel angle(45) labsize(vsmall) nolabels) /// 
		   ylabel(0 (10) 90, nogrid axis(2) labsize(small)) /// 
			scale(1) subtitle(,bcolor(white) nobox size(small)) xsize(15) ysize(10) ///
			graphregion(color(white) ) ///
			plotregion(color(white) istyle(none) ) ///
			name(Figure_1, replace)
end

* plot the graph (preserve data, since data structure will be altered)
preserve 
	collapse (mean) nr_* r_* gfshr gmshr gfcarehrs gmcarehrs cplsumwkhrs ret, by(c) // generate appropriate data structure for plotting
	figure1	// call small program
restore

* export plotted graph to different formats 
graph save Figure_1 "${logDir}/Figure_1_editable_STATA.gph", replace
graph save Figure_1 "${logDir}/Figure_1.gph", replace asis

graph export "${logDir}/Figure_1.pdf", replace name(Figure_1)
graph export "${logDir}/Figure_1.emf", replace name(Figure_1)
graph export "${logDir}/Figure_1.eps", as(eps) replace name(Figure_1) preview(off) logo(off) 
graph export "${logDir}/Figure_1.tif", as(tif) replace name(Figure_1) width(1081) 
