/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Regression models (pooled OLS) for grandfather's share (30-2_pooled_regression_models.do), 
* executed by analysis master 30_analysis.do
*
* Provides estimates for
* - Model 1 (pooled OLS), Table 3
* - Model 2 (pooled OLS), Table 3
* - Model 4 (pooled OLS), Table 4
* - Figure 2 (country effects plot for Model 1 and 2), Figure 2
*
* Note: Model 3 is estimated in 
*		30-3_fixed_effects_regression_model.do
*
***********************************************************************/

* load analytical dataset
use "${tempDir}/20_variables_imputation.dta", clear

* drop cases with missing share of grandfather (gfshr) since there are no hours performed by the couple
drop if cplsumwkhrs_impmod3==0	// -120 observations


**
* Generate some variables needed for the analysis
**
* generate variables for Grandfather's share and 
* couple's weekly hours of grandparenting based 
* on imputation (model 3)
gen gfshr = gfshr_impmod3
gen cplsumwkhrs = cplsumwkhrs_impmod3

* top code couple's week hours of care to 120 
replace cplsumwkhrs = 120 if cplsumwkhrs > 120 & cplsumwkhrs < .

* check that there are no missing values
misstable summarize gfshr
assert gfshr < .

* variable classifing countries ("Nordic", "Continental", "Southern")
* North: Sweden, Denmark
* Middle: Germany, Austria, Belgium, Netherlands, France
* South: Spain, Italy, Greece
recode country (13 18 = 1 "Nordic") (11 12 14 23 17 = 2 "Continental") (15 16 19 = 3 "Southern"), gen(class)

* generate wave2 dummy
gen wave2 = wave==2

* number of children to whom care is provided
* generate a variable: care to more than 1 child
capt drop caretomore
gen caretomore = caredchild > 1

* generate dummies for limitation status of couples
tab cpllimit, gen(lim_)

* Modelling jobshare of grandmother
* (since jobshare is reasonable defined only for working couples model an interaction effect nonret*gmjobshr)
gen nonret = empcf < 5
gen ret = empcf==5
gen nr_gmjs = gmjobshr*nonret


*************************************************
* Pooled linear regression models
* Models 1 and 2 
*************************************************

* "effect coding for country dummies"
* (note if groups are unbalanced this represents the mean of the group means, an unweighted grand mean, 
* which is in our case not identical to the grand mean considering different sample sizes of countries;
* it just refers to the mean of mean of countries)
* to have a meaningful interpretation, we also take the unweighted mean for centering the other variables
capt drop first
* To be consistent to the effect coding approach, center other variables by the unweighted grand mean
by country, sort: gen first = _n==1
foreach var of varlist cplage cplygfo cplygmo shortdist cplisgt3 /// 
		               g?jobhrs mincycage gfygcnotown cplsumwkhrs /// 
					   wave2 cplcohab caretomore lim_1 lim_2 lim_3 lim_4 {
	by country, sort: egen me1`var' = mean(`var')
	sum me1`var' if first==1
	gen me2`var' = `r(mean)'
	gen EC`var' = `var' - me2`var'
	drop me1`var' me2`var'
}

* effect code country dummies (take Austria as ref. cat.)
* (note: interpretation with reference to the unweighted grand mean 
* [=mean of country means], not the overall mean in europe)
tab country, gen(c_)

foreach var of varlist c_2-c_10 {
	gen EC`var' = `var' - c_1
	loc lab: variable label `var'
	lab var EC`var' "`lab'"
}

* unweighted grand mean = mean over means of countries
* show: 
by country, sort: egen megfshr = mean(gfshr)
sum megfshr if first==1
regress gfshr ECc_2-ECc_10
regress gfshr ECcplisgt3 ECc_2-ECc_10

**
* Model 1 
* (fit pooled OLS model with cluster robust standard errors)
**
regress gfshr ECcplage ECcplygfo ECcplygmo ECcplisgt3 ECshortdist ECmincycage ///
			  ECgfygcnotown ECcplsumwkhrs ECwave2 ECcplcohab ECcaretomore ///
			  EClim_2 EClim_3 EClim_4  ECc_2-ECc_10 , vce(cluster hhid)
est store model1

**
* Model 2 
* (including "GMs share of market work" and "Inactive/retired couple")
* (fit pooled OLS model with cluster robust standard errors)
**
regress gfshr ECcplage ECcplygfo ECcplygmo ECcplisgt3 ECshortdist ECmincycage ///
			  ECgfygcnotown ECcplsumwkhrs ECwave2 ECcplcohab ECcaretomore ///
			  EClim_2 EClim_3 EClim_4  ECc_2-ECc_10 ///
			  nr_gmjs ret, vce(cluster hhid)
est store model2
				  
******************************
* Table 3. Pooled and Fixed-Effects Regression Models for Grandfathers Share of Grandparenting
* (only pooled models) 
******************************
* >>>>>
estout model1 model2 , cells(b(fmt(%9.3f) star) se) ///
				  stats(N N_clust r2 df_m rho, fmt(%9.3g) labels("Observations" "Clusters (Couples)" "R-sqr." "Degrees of Freedom" "rho")) /// 
				  nolz /// 
				  starlevels(+ .1 * .05 ** .01 *** .001) ///
				  varlabels(_cons "Constant (GF's share)" ///
							ECcplage "Mean age (cent.)" ///
							ECshortdist "Short distance (cent.)" ///
							ECcplisgt3 "Post-secondary education (cent.)" ///
							ECmincycage "Youngest GC's age (cent.)" ///
							ECgfygcnotown "Youngest grandchild not from GF (cent.)" ///
							ECcplsumwkhrs "Caring hours per week (cent.)" ///
							EClim_1 "Sick/Limit.: none (cent.)" ///
							EClim_2 "Sick/Limit.: only GF (cent.)" ///
							EClim_3 "Sick/Limit.: only GM (cent.)" ///
							EClim_4 "Sick/Limit.: both (cent.)" ///
							ECc_1 "Austria" ///
							ECc_2 "Germany" ///
							ECc_3 "Sweden" ///
							ECc_4 "Netherlands" ///
							ECc_5 "Spain" ///
							ECc_6 "Italy" ///
							ECc_7 "France" ///
							ECc_8 "Denmark" ///
							ECc_9 "Greece" ///
							ECc_10 "Belgium" ///
							nr_gmjs "Grandmother's share of market work" ///
							ret "Inactive/retired couple" ///
							ECwave2 "Wave 2 (cent.)" ///
							ECcplygfo "Years GF is older (cent.)" ///
							ECcplygmo "Years GM is older (cent.)" ///
							ECcplcohab "Cohabiting with a child (cent.)" ///
							ECcaretomore "Care to > 1 child (cent.)" ///
							) /// 
				  order(_cons nr_gmjs ret ///
					     ECc_2 ECc_3 ECc_4 ECc_5 ECc_6 ECc_7 ECc_8 ECc_9 ECc_10  ///
						 ECcplage ECcplygfo ECcplygmo ///
						 ECcplisgt3 ECcplcohab ECcaretomore ECcplsumwkhrs /// 
						 ECshortdist ECmincycage ECgfygcnotown ///
						 EClim_2 EClim_3 EClim_4 ///
						 ECwave2) ///
				  varwidth(35) ///
				  modelwidth(15) ///
				  legend ///
				  mlabels("Model 1" "Model 2")

* Coefficient for Austria (deviation from the grand mean) is calculated manually
* ... for Model 1
est restore model1
lincom -1*(ECc_2 + ECc_3 + ECc_4 + ECc_5 + ECc_6 + ECc_7 + ECc_8 + ECc_9 + ECc_10)
* ... for Model 2
est restore model2
lincom -1*(ECc_2 + ECc_3 + ECc_4 + ECc_5 + ECc_6 + ECc_7 + ECc_8 + ECc_9 + ECc_10)
* <<<<<
******************************


******************************
* Figure 2. Country Effects Plots Conditional on Covariates
******************************
* >>>>>
* For both models, point estimates and confidence intervals for country 
* coefficients are calculated and plotted. 
/*
	Note: this procedure compares coefficients between countries 
		  (i.e. the deviatation from the overall grand mean). It does not
		  compare total levels of grandfathers' shares between countries, which 
		  would need to account for the standard error of the constant (= the grand mean). 
*/
 
* restore estimates from Model 1
est restore model1

gen ctry = . 
gen mean1 = .
gen lb1 = .
gen ub1 = .

foreach num of numlist 1/10 {
	replace ctry = `num' in `num' 
}
lab def ctry 1  "Austria", modify
lab def ctry 2  "Germany", modify
lab def ctry 3  "Sweden", modify
lab def ctry 4  "Netherlands", modify
lab def ctry 5  "Spain", modify
lab def ctry 6  "Italy", modify
lab def ctry 7  "France", modify
lab def ctry 8  "Denmark", modify
lab def ctry 9  "Greece", modify
lab def ctry 10 "Belgium", modify
lab val ctry ctry 

* t-value for constructing 95% confidence interval
local tpoint = invttail(4275, .025)

local cons = 0

* Austria (ref. cat.)
* alt. method (better for evaluating effects!)
lincom -1*(ECc_2+ECc_3+ECc_4+ECc_5+ECc_6+ECc_7+ECc_8+ECc_9+ECc_10) 
* point estimate 
replace mean1 =  `cons' + r(estimate) in 1
* intervall estimate (lb = lower bound, ub = upper bound)
replace lb1 = `cons' + (r(estimate)-`tpoint'*r(se)) in 1
replace ub1 = `cons' + (r(estimate)+`tpoint'*r(se)) in 1

* Estimates for other countries
foreach num of numlist 2/10 {
	lincom ECc_`num'
	replace mean1 = `cons' + r(estimate) in `num'
	replace lb1 = `cons' + (r(estimate)-`tpoint'*r(se)) in `num'
	replace ub1 = `cons' + (r(estimate)+`tpoint'*r(se)) in `num'
}

* restore estimates from Model 2
est restore model2 

gen mean2 = .
gen lb2 = .
gen ub2 = .

* t-value for constructing 95% confidence interval
local tpoint = invttail(4275, .025)

* constant
local cons = 0

* Austria (ref. cat.)
lincom -1*(ECc_2+ECc_3+ECc_4+ECc_5+ECc_6+ECc_7+ECc_8+ECc_9+ECc_10) 
replace mean2 =  `cons' + r(estimate) in 1
replace lb2 = `cons' + (r(estimate)-`tpoint'*r(se)) in 1
replace ub2 = `cons' + (r(estimate)+`tpoint'*r(se)) in 1

* Other countries
foreach num of numlist 2/10 {

	* a) 
	lincom ECc_`num'
	replace mean2 = `cons' + r(estimate) in `num'
	replace lb2 = `cons' + (r(estimate)-`tpoint'*r(se)) in `num'
	replace ub2 = `cons' + (r(estimate)+`tpoint'*r(se)) in `num'
}



* recode ctry for fitting the ordering convention of countries
recode ctry (3 = 1 "Sweden") ///
			(8 = 2 "Denmark") ///
			(4 = 3 "Netherlands") ///
			(10= 4 "Belgium") ///
			(2 = 5 "Germany") ///
			(7 = 6 "France") ///
			(1 = 7 "Austria") ///
			(6 = 8 "Italy") ///
			(5 = 9 "Spain") ///
			(9 = 10 "Greece"), gen(ctryorder)

sort ctryorder

* Effects based on model 1a & 1b		
* Marginsplot
clonevar x1 = ctryorder 
clonevar x2 = ctryorder

replace x1 = x1-0.125
replace x2 = x2+0.125

* plot effect plot
set scheme s2mono
twoway  (rcap lb1 ub1 x1 in 1/10, lwidth(thin) lcolor(gs8)) ///
		(scatter mean1 x1 in 1/10, msym(D) msize(small)  mlwidth(none) mcolor(gs0)) ///
		(rcap lb2 ub2 x2 in 1/10, lwidth(thin) lcolor(gs8)) ///
		(scatter mean2 x2 in 1/10, msym(O) mfcolor(white) msize(medsmall) mlwidth(medthin)  mcolor(gs0)), ///
		xlabel(1(1)10, valuelabel labsize(small) angle(45)) ///
		yline(0, lpattern(shortdash) lcolor(gs10) lwidth(thin))  ///
		ylabel(-10 (2.5) 10, glcolor(gs15) glwidth(vthin) labsize(small) angle(0)) ///
		ysize(10) xsize(13) ///
		ytitle("Effect size (%-points)", margin(vsmall) size(small) ) xtitle("") ///
		graphregion(color(white)) plotregion(color(white)) ///
		legend(lab(1 "95% CI (Model 1a)") lab(2 "Model 1") /// 
			   lab(3 "95% CI (Model 1b)") lab(4 "Model 2") size(small) /// 
			   order(2 4) cols(1) ring(0) pos(2) region(lwidth(vthin) lcolor(white)) ///
			   symxsize(*.5)) ///
		saving("${logDir}/Figure_2_editable_STATA.gph", replace) name(Figure_2, replace)
* export to different output formats
graph save Figure_2 "${logDir}/Figure_2.gph", replace asis
graph export "${logDir}/Figure_2.pdf", replace name(Figure_2)
graph export "${logDir}/Figure_2.emf", replace name(Figure_2)
graph export "${logDir}/Figure_2.eps", as(eps) replace name(Figure_2)
graph export "${logDir}/Figure_2.tif", as(tif) replace name(Figure_2) width(1081) 

* >>>>>
******************************


*************************************************
* Table 4. Results from Pooled Regression Including Interactions with Country Groups (Model 4)
*************************************************
* >>>>>
* Model 4 extends Model 2 by including 
* interaction terms of country group and the retirement and jobshare variables

* Centering the variables to grandmean of class specific countries
* For each variable
* 1) calculate the country-specific mean 
* 2) calculate the mean of country-specific means within each class of countries 
*	 (i.e. north, south, middle)
* 3) center the variable at the group-specific grand mean
capt drop first
capt drop EC*
capt drop me1* me2*
by country, sort: gen first = _n==1
foreach var of varlist cplage cplygfo cplygmo cplcohab caretomore shortdist cplisgt3 g?jobhrs mincycage gfygcnotown cplsumwkhrs wave2 lim_1 lim_2 lim_3 lim_4 {
	by country, sort: egen me1`var' = mean(`var')
	by class (country), sort: egen me2`var'= mean(me1`var') if first==1
	by country (first), sort: replace me2`var' = me2`var'[_N]
	gen EC`var' = `var' - me2`var'
}

* generate a dummy set for the country groups
capt drop class_*
tab class, gen(class_)
foreach var of varlist class_1 class_2 class_3 {
	gen EC`var' = `var' - class_2
	loc lab: variable label `var'
	lab var EC`var' "`lab'"
}


capt drop class_?_*
gen class_1_c1 = c_3
gen class_1_c2 = c_8

gen class_2_c1 = c_1
gen class_2_c2 = c_2
gen class_2_c3 = c_4
gen class_2_c4 = c_7
gen class_2_c5 = c_10

gen class_3_c1 = c_5
gen class_3_c2 = c_6
gen class_3_c3 = c_9


foreach var of varlist class_1_c1 class_1_c2 {
	gen EC`var' = `var' - class_1_c1 
	loc lab: variable label `var'
	lab var EC`var' "`lab'"
}

foreach var of varlist class_2_c1-class_2_c5 {
	gen EC`var' = `var' - class_2_c1 
	loc lab: variable label `var'
	lab var EC`var' "`lab'"
}
foreach var of varlist class_3_c1-class_3_c3 {
	gen EC`var' = `var' - class_3_c1 
	loc lab: variable label `var'
	lab var EC`var' "`lab'"
}

**
* Model 4
**
* Model design: 
* - set the constant to the grand mean over country groups for healthy and active couples with a male earner
* - center independent variables at country-group means, except for market share, inactive dummy, limitation dummies
* - effect-code country group dummies (ref. middle group)
* - effect-code country dummies within groups
* - interact effect-coded group dummies with respective country dummies within group   
regress gfshr  nr_gmjs ret ///
			   c.class_1#(c.nr_gmjs c.ret) c.class_3#(c.nr_gmjs c.ret) ///
		       ECclass_1 ECclass_3 ///
			   ECcplage ECcplygfo ECcplygmo ECshortdist ECcplisgt3 ECmincycage ECgfygcnotown ECcplsumwkhrs EClim_2 EClim_3 EClim_4 ECwave2 ///
			   ECcplcohab ECcaretomore ///
			   c.ECclass_1#(c.ECclass_1_c2) ///
			   c.ECclass_3#(c.ECclass_3_c2 c.ECclass_3_c3) ///
			   c.ECclass_2_c2 c.ECclass_2_c3 c.ECclass_2_c4 c.ECclass_2_c5 , vce(cluster hhid)			   
est store model4


* Numbers for Table 4

* restore model 4
est restore model4			   
* Coefficient for Continental countries
* market share
lincom nr_gmjs , cformat(%9.3f)
* ret/inactive
lincom ret, cformat(%9.3f)
* constant
lincom _cons - ECclass_1 - ECclass_3 , cformat(%9.3f)

* Coefficient for Nordic countries
* market share
lincom nr_gmjs + c.class_1#c.nr_gmjs, cformat(%9.3f)
* ret/inactive (not significant)
lincom ret + c.class_1#c.ret, cformat(%9.3f)
* constant
lincom _cons + ECclass_1 , cformat(%9.3f)

* Coefficient for Southern countries
* market share (marginal significant at 10%)
lincom nr_gmjs + c.class_3#c.nr_gmjs, cformat(%9.3f)
* ret/inactive 
lincom ret + c.class_3#c.ret, cformat(%9.3f)
* constant
lincom _cons + ECclass_3 , cformat(%9.3f)

* Difference in constant between Nordic and Continental (significant)
lincom (_cons + ECclass_1)-(_cons - ECclass_1 - ECclass_3), cformat(%9.3f)
* Difference in effects
lincom (nr_gmjs + c.class_1#c.nr_gmjs)-nr_gmjs, cformat(%9.3f)
lincom (ret + c.class_1#c.ret)-ret, cformat(%9.3f)

* Difference in constant between Southern and Continental (not significant)
lincom (_cons + ECclass_3)-(_cons - ECclass_1 - ECclass_3), cformat(%9.3f)
* Difference in effects
lincom (nr_gmjs + c.class_3#c.nr_gmjs)-nr_gmjs, cformat(%9.3f)
lincom (ret + c.class_3#c.ret)-ret, cformat(%9.3f)
* <<<<<
