/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Regression model (fixed effects) for grandfather's share (30-3_fixed_effects_regression_model.do), 
* executed by analysis master 30_analysis.do
*
* The syntax in this file 
* - checks the selectivity of the fixed-effects sample (the longitudinal sample)
* - provides estimates for Model 3 (fixed effects regression), Table 3
*
* Note: Contrary to the pooled OLS regression, the fixed-effects model takes into
*		acount only within-couple variation to estimate the effects of 
*		couples' market work status. Since it relates changes of independent variables 
*	    to changes in the dependent variable (within-transformation), 
*		only time-varying predictors can be included in the model.
*
* Note: Model 1, 2, and 4, are estimated in 
*		30-2_pooled_regression_models.do
*
***********************************************************************/


* load analytical dataset
use "${tempDir}/20_variables_imputation.dta", clear

* drop those cases with missing share of grandfather (gfshr) since there are no hours performed by the couple
drop if cplsumwkhrs_impmod3==0	// -120 observations

**
* Generate some variables needed for the analysis
**
* generate variables for Grandfather's share and 
* couple's weekly hours of grandparenting based 
* on imputation (model 3)
gen gfshr = gfshr_impmod3
gen cplsumwkhrs = cplsumwkhrs_impmod3

* top code couple's week hours of care to 120 
replace cplsumwkhrs = 120 if cplsumwkhrs > 120 & cplsumwkhrs < .

* check that there are no missing values
misstable summarize gfshr
assert gfshr < .

* variable classifing countries ("Nordic", "Continental", "Southern")
* North: Sweden, Denmark
* Middle: Germany, Austria, Belgium, Netherlands, France
* South: Spain, Italy, Greece
recode country (13 18 = 1 "Nordic") (11 12 14 23 17 = 2 "Continental") (15 16 19 = 3 "Southern"), gen(class)

* generate wave2 dummy
gen wave2 = wave==2

* number of children to whom care is provided
* generate a variable: care to more than 1 child
capt drop caretomore
gen caretomore = caredchild > 1

* generate dummies for limitation status of couples
tab cpllimit, gen(lim_)

* Modelling jobshare of grandmother
* (since jobshare is reasonable defined only for working couples model an interaction effect nonret*gmjobshr)
gen nonret = empcf < 5
gen ret = empcf==5
gen nr_gmjs = gmjobshr*nonret


***
* Selectivity of the fixed-effects sample (see endnote 8 in paper)
***
preserve
	keep if wave==1
	gen fesample = waves==2
	* logistic regression on being in the FE-sample
	logit fesample cplisgt4 gfshr i.empcf gfjobshr cplage shortdist mincycage cplsumwkhrs gfygcnotown lim_2 lim_3 lim_4 i.country
	est table , star b(%9.3f) eform
	* Country-differences
	tab country fesample , col nofreq
	tab country fesample , row nofreq
	* 
	tabstat mincycage cplsumwkhrs, by(fesample) f(%9.2f)
	/*
	Results: 
	- country differences due to differential panel attrition by country
	- higher attrition in Spain, the Netherlands, lower attrition in Italy, 
	  Denmark, Greece and Belgium
	- no evidence for selectivity regarding education, age, employment/retirement status, health
	- on average, youngest grandchildren are a bit younger in the fixed-effects sample
	- on average, caring workload is a bit higher in the fixed-effects sample
	*/
restore

******************************
* Table 3. Pooled and Fixed-Effects Regression Models for Grandfathers Share of Grandparenting
* (only fixed effects model) 
******************************
* >>>>>	
* keep couples participating in both waves
by hhid (wave), sort: gen N = _N
keep if N==2
keep hhid wave wave2 nr_gmjs nonret ret country cplcohab caretomore gfjobshr lim_* cpllimit gmjobshr g?care* gmshr* gfshr* g?retired g?ep005 empcf mincycage cplsumwkhrs shortdist cplisgt4 hisced* cplage gfretired gfep005 
sort hhid wave

gen ID = _n
replace ID = ID[_n-1] if hhid==hhid[_n-1] & _n > 1
xtset ID wave 
xtdes

* using unweighted grand mean centered variables (to be consistent with the OLS model above)
by country, sort: gen first = _n==1
foreach var of varlist cplsumwkhrs mincycage shortdist wave2 cplcohab caretomore lim_1 lim_2 lim_3 lim_4  {
	by country, sort: egen me1`var' = mean(`var')
	sum me1`var' if first==1
	gen me2`var' = `r(mean)'
	gen EC`var' = `var' - me2`var'
	drop me1`var' me2`var'
}


**
* Model 3
**
xtreg gfshr nr_gmjs ret ECcplcohab ECcaretomore ECcplsumwkhrs ECmincycage ECshortdist ECwave2 EClim_2 EClim_3 EClim_4, fe 
estadd scalar N_clust = e(N_g)

est store model3

estout model3, cells(b(fmt(%9.3f) star) se) ///
				  stats(N N_clust r2 df_m rho, fmt(%9.3g) labels("Observations" "Clusters (Couples)" "R-sqr." "Degrees of Freedom" "rho")) /// 
				  nolz /// 
				  starlevels(+ .1 * .05 ** .01 *** .001) ///
				  varlabels(_cons "Constant (GF's share)" ///
							ECcplage "Mean age (cent.)" ///
							ECshortdist "Short distance (cent.)" ///
							ECcplisgt3 "Post-secondary education (cent.)" ///
							ECmincycage "Youngest GC's age (cent.)" ///
							ECgfygcnotown "Youngest grandchild not from GF (cent.)" ///
							ECcplsumwkhrs "Caring hours per week (cent.)" ///
							EClim_1 "Sick/Limit.: none (cent.)" ///
							EClim_2 "Sick/Limit.: only GF (cent.)" ///
							EClim_3 "Sick/Limit.: only GM (cent.)" ///
							EClim_4 "Sick/Limit.: both (cent.)" ///
							ECcplcohab "Cohabiting with a child (cent.)" ///
							ECcaretomore "Care to > 1 child (cent.)" ///
							nr_gmjs "Grandmother's share of market work" ///
							ret "Inactive/retired couple" ///
							ECwave2 "Wave 2 (cent.)" ///
							) /// 
				  order(_cons nr_gmjs ret ECcplage ECcplisgt3 ECcaretomore ECcplcohab ECshortdist ECmincycage  ECcplsumwkhrs ) ///
				  varwidth(35) ///
				  modelwidth(15) ///
				  legend ///
				  mlabels("FE Model")
* <<<<<<
